﻿using Simulator.ViewModels;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Windows.ApplicationModel.Core;
using Windows.Devices.Bluetooth.Rfcomm;
using Windows.Networking.Sockets;
using Windows.Storage.Streams;

namespace Simulator
{
    class BluetoothManager
    {
        private RfcommServiceProvider _provider;
        private StreamSocket _socket;
        private MainPage mainpage;
        private PageViewModel pageViewModel;

        public BluetoothManager(MainPage mainPage, PageViewModel pageViewModel)
        {
            this.mainpage = mainPage;
            this.pageViewModel = pageViewModel;
        }

        public async void Initialize()
        {

            // Initialize the provider for the hosted RFCOMM service
            try
            {
                _provider = await RfcommServiceProvider.CreateAsync(RfcommServiceId.FromUuid(new Guid("3b29c7a5-13b5-42f3-8fb7-8cb80f35aa68")));

                // Create a listener for this service and start listening
                StreamSocketListener listener = new StreamSocketListener();
                listener.ConnectionReceived += OnConnectionReceived;

                var rfcomm = _provider.ServiceId.AsString();

                await listener.BindServiceNameAsync(
                    _provider.ServiceId.AsString(),
                    SocketProtectionLevel
                        .BluetoothEncryptionAllowNullAuthentication);

                // Set the SDP attributes and start advertising
                InitializeServiceSdpAttributes(_provider);
                _provider.StartAdvertising(listener, true);
            }
            catch (Exception e)
            {
                Debug.Write(e.Message);
            }
        }

        const uint SERVICE_VERSION_ATTRIBUTE_ID = 0x0300;
        const byte SERVICE_VERSION_ATTRIBUTE_TYPE = 0x0A;   // UINT32
        const uint SERVICE_VERSION = 200;

        const UInt16 SdpServiceNameAttributeId = 0x100;
        const byte SdpServiceNameAttributeType = (4 << 3) | 5;
        const string SdpServiceName = "Bluetooth Rfcomm Inverter Service";

        void InitializeServiceSdpAttributes(RfcommServiceProvider provider)
        {
            DataWriter writer = new DataWriter();

            // First write the attribute type
            writer.WriteByte(SERVICE_VERSION_ATTRIBUTE_TYPE);
            // Then write the data
            writer.WriteUInt32(SERVICE_VERSION);

            IBuffer data = writer.DetachBuffer();
            provider.SdpRawAttributes.Add(SERVICE_VERSION_ATTRIBUTE_ID, data);
        }


        private async void OnConnectionReceived(StreamSocketListener sender, StreamSocketListenerConnectionReceivedEventArgs args)
        {
            // Stop advertising/listening so that we're only serving one client
            _provider.StopAdvertising();

            try
            {
                _socket = args.Socket;
                Debug.Write("ok");
            }
            catch (Exception e)
            {
                Debug.Write(e);
                return;
            }

            await CoreApplication.MainView.CoreWindow.Dispatcher.RunAsync(Windows.UI.Core.CoreDispatcherPriority.High, () => {

                this.mainpage.DataContext = this.pageViewModel;
            });

            
        }
    }
}
