﻿using Simulator.Bluetooth;
using Simulator.Model;
using Simulator.ViewModels;
using Simulator.XML;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.System.Threading;
using Windows.UI.Core;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;

// La plantilla de elemento Página en blanco está documentada en https://go.microsoft.com/fwlink/?LinkId=402352&clcid=0xc0a

namespace Simulator
{
    /// <summary>
    /// Página vacía que se puede usar de forma independiente o a la que se puede navegar dentro de un objeto Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        private ConnectionManager connectionManager;
        private BluetoothManager bluetoothManager;

        private Random rnd = new Random();

        public MainPage()
        {
            this.InitializeComponent();
            //bluetoothManager = new BluetoothManager();
            //bluetoothManager.Initialize();
            this.InitializeSimulator();
        }

        private async void InitializeSimulator()
        {
            XMLReader reader = new XMLReader();
            IEnumerable<Parameter> parameters = await reader.ReadParameters();
            IEnumerable<MonitorParameter> monitorParameters = await reader.ReadMonitorParameters();
            Alarm alarm = await reader.ReadAlarms();
            IList<ParameterViewModel> parameterViewModels = new List<ParameterViewModel>();
            foreach (Parameter parameter in parameters)
            {
                parameterViewModels.Add(new ParameterViewModel(parameter));
            }

            IList<MonitorParameterViewModel> monitorParameterViewModels = new List<MonitorParameterViewModel>();
            foreach (MonitorParameter parameter in monitorParameters)
            {
                monitorParameterViewModels.Add(new MonitorParameterViewModel(parameter));
            }

            TimeSpan period = TimeSpan.FromSeconds(1);

            ThreadPoolTimer PeriodicTimer = ThreadPoolTimer.CreatePeriodicTimer( async (source) =>
            {
                await Dispatcher.RunAsync(CoreDispatcherPriority.High,
                    () =>
                    {
                        foreach (MonitorParameter item in monitorParameters)
                        {
                            item.Value = rnd.Next(-1000, 1000);
                        }
                    });

            }, period);

            PageViewModel pageViewModel = new PageViewModel(alarm, parameterViewModels, monitorParameterViewModels);
            //PageViewModel pageViewModel = new PageViewModel();
            pageViewModel.Model = "Inverter1";
            pageViewModel.Firmware = "1.1x";
            pageViewModel.SerialNumber = "12345";
            pageViewModel.Motor = "145-RT";
            connectionManager = new ConnectionManager(parameters, monitorParameters, alarm, pageViewModel, this);
            connectionManager.Initialize();
            
           //this.DataContext = pageViewModel;
            //bluetoothManager = new BluetoothManager(this, pageViewModel);
            //bluetoothManager.Initialize();
        }
    }
}
