﻿
using Simulator.Model;
using System.Collections.Generic;
using System.ComponentModel;

namespace Simulator.ViewModels
{
	public class PageViewModel : INotifyPropertyChanged
	{
        private Alarm alarm;
        private IList<ParameterViewModel> parameters;
        private IList<MonitorParameterViewModel> monitorParameters;
        private bool isStopped;
        private bool isRunning;
        private string state;

        public PageViewModel(Alarm alarm, IList<ParameterViewModel> parameters, IList<MonitorParameterViewModel> monitorParameters)
		{
            this.alarm = alarm;
            this.parameters = parameters;
            this.monitorParameters = monitorParameters;
            this.isStopped = true;
            this.state = "Disconnected";
		}

        public PageViewModel()
        {
            alarm = new Alarm() { EventCodes = new List<int>() };
            this.parameters = new List<ParameterViewModel>();
            this.monitorParameters = new List<MonitorParameterViewModel>();
            this.isStopped = true;
            this.state = "Disconnected";
        }
        public event PropertyChangedEventHandler PropertyChanged;

        public IList<ParameterViewModel> Parameters
        {
            get
            {
                return this.parameters;
            }
        }

        public IList<MonitorParameterViewModel> MonitorParameters
        {
            get
            {
                return this.monitorParameters;
            }
        }

        public int SelectedAlarm
        {
            set
            {
                if (alarm.Value != value)
                {
                    this.alarm.Value = value;
                    OnPropertyChanged("SelectedAlarm");
                }
            }
            get
            {
                return this.alarm.Value;
            }
        }

		public IList<int> Alarms
		{
			get
			{
				return this.alarm.EventCodes;
			}
		}

        public bool IsStopped
        {
            set
            {
                if (this.isStopped != value)
                {
                    this.isStopped = value;
                    OnPropertyChanged("IsStoped");
                }
            }
            get
            {
                return this.isStopped;
            }
        }

        public bool IsRunning
        {
            set
            {
                if (this.isRunning != value)
                {
                    this.isRunning = value;
                    OnPropertyChanged("IsRunning");
                }
            }
            get
            {
                return this.isRunning;
            }
        }

        public string State
        {
            set
            {
                if (this.state != value)
                {
                    this.state = value;
                    OnPropertyChanged("State");
                }
            }
            get
            {
                return this.state;
            }
        }

        public string Model { get; set; }
        public string Firmware { get; set; }
        public string SerialNumber { get; set; }
        public string Motor { get; set; }

        protected virtual void OnPropertyChanged(string propertyName)
		{
			if (PropertyChanged != null)
			{
				PropertyChanged(this,
					new PropertyChangedEventArgs(propertyName));
			}
		}
	}
}