﻿using Simulator.Model;
using System;
using System.Collections.Generic;
using System.ComponentModel;

namespace Simulator.ViewModels
{
	public class ParameterViewModel : INotifyPropertyChanged
	{
		private readonly Parameter model;

		public ParameterViewModel(Parameter parameter)
		{
			this.model = parameter;
            this.model.PropertyChanged += Model_PropertyChanged;
		}

        private void Model_PropertyChanged(object sender, PropertyChangedEventArgs e)
        {
            OnPropertyChanged("ParameterValue");
        }

        public event PropertyChangedEventHandler PropertyChanged;

		private string parameterName;
		private int parameterValue;

		public string ParameterName
		{
			get
			{
				return model.Name;
			}
		}

		public string ParameterValue
		{
			set
			{
                int enteredValue = 0;
                bool parsed = Int32.TryParse(value, out enteredValue);
				if (parsed && this.model.Value != enteredValue)
				{
					this.model.Value = enteredValue;
                    OnPropertyChanged("ParameterValue");
				}
			}
			get
			{
				return Convert.ToString(this.model.Value);
			}
		}

		public int ParameterMin
		{
			get
			{
				return model.Min;
			}
		}

		public int ParameterMax
		{
			get
			{
				return model.Max;
			}
		}

		public int ParameterDefault
		{
			get
			{
				return model.Default;
			}
		}

		public string ParameterDescription
		{
			get
			{
				return model.Description;
			}
		}

		public string ParameterUnit
		{
			get
			{
				return model.Unit;
			}
		}

		public string ParameterHelp
		{
			get
			{
				return model.Help;
			}
		}

		protected virtual void OnPropertyChanged(string propertyName)
		{
			if (PropertyChanged != null)
			{
				PropertyChanged(this,
					new PropertyChangedEventArgs(propertyName));
			}
		}
	}
}