﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using System.Xml.Linq;
using System.Reflection;
using System.IO;
using Simulator.Model;

namespace Simulator.XML
{
	public class XMLReader
	{
		public async Task<IEnumerable<Parameter>> ReadParameters()
		{
			List<Parameter> rawData = null;
			var assembly = typeof(XMLReader).GetTypeInfo().Assembly;
			Stream stream = assembly.GetManifestResourceStream("Simulator.XML.Inverter.xml");

			await Task.Factory.StartNew(delegate {
			            XDocument doc = XDocument.Load(stream);
				IEnumerable<Parameter> parameters = from s in doc.Root.Elements("Parameters").Elements("Configuration").Descendants("Parameter")
									  select new Parameter
									  {
					Index = Convert.ToUInt16(s.Attribute("Index").Value),
					Subindex = Convert.ToUInt16(s.Attribute("Subindex").Value),
					Min = Convert.ToInt32(s.Attribute("Min").Value),
					Max = Convert.ToInt32(s.Attribute("Max").Value),
					Default = Convert.ToInt32(s.Attribute("Default").Value),
					Unit = s.Attribute("Unit").Value,
					Name = s.Element("Name").Value,
					Help = s.Element("Help").Value,
					Description = s.Element("Description").Value
				};
                
			rawData = parameters.ToList();
			        });

            foreach (Parameter item in rawData)
            {
                item.Value = item.Default;
            }

            return rawData;
		}

		public async Task<IEnumerable<MonitorParameter>> ReadMonitorParameters()
		{
			List<MonitorParameter> rawData = null;
			var assembly = typeof(XMLReader).GetTypeInfo().Assembly;
			Stream stream = assembly.GetManifestResourceStream("Simulator.XML.Inverter.xml");

			await Task.Factory.StartNew(delegate
			{
				XDocument doc = XDocument.Load(stream);
				IEnumerable<MonitorParameter> parameters = from s in doc.Root.Elements("Parameters").Elements("Monitor").Descendants("Parameter")
	                                                 select new MonitorParameter
													{
														Index = Convert.ToUInt16(s.Attribute("Index").Value),
														Subindex = Convert.ToUInt16(s.Attribute("Subindex").Value),
														Unit = s.Attribute("Unit").Value,
														Name = s.Element("Name").Value,
														Description = s.Element("Description").Value
													};

				rawData = parameters.ToList();
			});

            Random rnd = new Random();
            foreach(MonitorParameter parameter in rawData)
            {
                parameter.Value = rnd.Next(-1000, 1000);
            }

			return rawData;
		}

		public async Task<Alarm> ReadAlarms()
		{
			Alarm rawData = null;
			var assembly = typeof(XMLReader).GetTypeInfo().Assembly;
			Stream stream = assembly.GetManifestResourceStream("Simulator.XML.Inverter.xml");

			await Task.Factory.StartNew(delegate
			{
				XDocument doc = XDocument.Load(stream);
                Alarm alarm = new Alarm();
                alarm.EventCodes = new List<int> { 0 };
                IEnumerable<XElement> alarms = from s in doc.Root.Elements("Alarms").Descendants("Alarm") select s;
                foreach(XElement element in alarms)
                {
                    alarm.EventCodes.Add(Convert.ToInt32(element.Attribute("EventCode").Value));
                }

                alarm.Value = 0;

                rawData = alarm;
			});

            rawData.Index = 1000;
            rawData.SubIndex = 1;
	        return rawData;
		}
	}
}
